==> ksnuffle-0.1.tgz: ksnuffle-0.1/ksnuffle/knd_replay.h <==
/***************************************************************************
                          knd_replay.h  -  description                              
                             -------------------                                         
    begin                : Thu Mar 25 14:26:46 GMT 1999
                                           
    copyright            : (C) 1999 by Mike Richardson                         
    email                : mike@quaking.demon.co.uk                                     
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   * 
 *                                                                         *
 ***************************************************************************/


#ifndef KSNUFFLEREP_H 
#define KSNUFFLEREP_H 

#ifdef		HAVE_CONFIG_H
#include	<config.h>
#endif 

#include	<kapp.h>
#include	<ktabctl.h>

#include	"ksnuffle.h"
#include	"knd_view.h"
#include	"knd_pcap.h"
#include	"knd_multi.h"
#include	"knd_config.h"
#include	"knd_confrep.h"

class	KNDReplay : public KNDView
{
	Q_OBJECT

public:
	KNDReplay (KNDApp *, KNDMulti *, int) ;

	virtual	~KNDReplay () ;

virtual	void	timerTick 	(long) ;
virtual	void	writeConfig	(KConfig *)	;

virtual	void	viewStop	() ;
virtual	void	viewStart	() ;
virtual	void	viewFreeze	() ;
virtual	void	viewResume	() ;

private	:

	KNDConfRep	*config    ;
}	;

#endif // KSNUFFLEREP_H

==> ksnuffle-0.6.tgz: ksnuffle-0.6/ksnuffle/knd_replay.h <==
/***************************************************************************
                          knd_replay.h  -  description                              
                             -------------------                                         
    begin                : Thu Mar 25 14:26:46 GMT 1999
                                           
    copyright            : (C) 1999 by Mike Richardson                         
    email                : mike@quaking.demon.co.uk                                     
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   * 
 *                                                                         *
 ***************************************************************************/


#ifndef 	KND_REPLAY_H 
#define 	KND_REPLAY_H 


#include	"ksnuffle.h"
#include	"knd_view.h"

class	KNDReplay : public KNDView
{
	Q_OBJECT

	KNDPCapRep	*repcap	;

public:
	KNDReplay (QWidget *, KNDApp *, KNDMulti *, int) ;
virtual~KNDReplay () ;

	virtual	MType	getMType () ;
}	;

#endif // KND_REPLAY_H
